
# Slot: clinical modifier qualifier


Used to characterize and specify the phenotypic abnormalities defined in the Phenotypic abnormality subontology, with respect to severity, laterality, age of onset, and other aspects

URI: [biolink:clinical_modifier_qualifier](https://w3id.org/biolink/vocab/clinical_modifier_qualifier)


## Domain and Range

[Association](Association.md) &#8594;  <sub>0..1</sub> [ClinicalModifier](ClinicalModifier.md)

## Parents

 *  is_a: [association slot](association_slot.md)

## Children


## Used by

